@@ -32,13 +32,13 @@ class WpSocketClient:
 
     async def async_on_connected(self):
         """Socket connected notifications"""
-        _LOGGER.debug('connected {}', self._host)
+        _LOGGER.debug('connected %s', self._host)
 
     async def async_connect(self) -> bool:
         """Socket connect"""
         await self.async_wait_for_disconnect()
 
-        _LOGGER.debug('connecting to server {}', self._host)
+        _LOGGER.debug('connecting to server %s', self._host)
         try:
             asyncio.set_event_loop(self._loop)
             self._reader, self._writer = await asyncio.wait_for(
@@ -55,14 +55,14 @@ class WpSocketClient:
             self._wait_tasks = asyncio.wait(tasks)
             return True
         except Exception as ex:
-            _LOGGER.error('connection error, {}, {}', self._host, ex)
+            _LOGGER.error("connection error, %s, %s", self._host, ex)
             self.disconnect()
         return False
 
     async def _async_reconnect(self):
         """Socket reconnect"""
         wait_time = self._retry_cnt * 5 if self._retry_cnt < 12 else 60
-        _LOGGER.debug('reconnect connect, wait {}s', wait_time)
+        _LOGGER.debug('reconnect connect, wait %d s', wait_time)
         await asyncio.sleep(wait_time)
         self._retry_cnt += 1
         if not await self.async_connect():
@@ -84,9 +84,9 @@ class WpSocketClient:
             except asyncio.TimeoutError:
                 continue
             except Exception as ex:
-                _LOGGER.error('message handler error, {}', ex)
+                _LOGGER.error('message handler error, %s', ex)
 
-        _LOGGER.debug('message handler end ')
+        _LOGGER.debug('message handler end')
 
     async def _async_reader(self):
         """Socket read packet"""
@@ -99,10 +99,10 @@ class WpSocketClient:
                     self._loop.create_task(self._async_reconnect())
                     break
 
-                _LOGGER.debug('Received [{}]: {}', len(data), data.hex())
+                _LOGGER.debug('Received [%d]: %s', len(data), data.hex())
                 await self._receive_packet_queue.put(data)
             except Exception as ex:
-                _LOGGER.error('reader error, {}', ex)
+                _LOGGER.error('reader error, %s', ex)
                 self._loop.create_task(self._async_reconnect())
                 break
         _LOGGER.debug('reader end')
@@ -116,12 +116,12 @@ class WpSocketClient:
                                                 timeout=_QUEUE_WAIT_TIMEOUT)
                 self._writer.write(packet)
                 await self._writer.drain()
-                _LOGGER.debug('Send [{}]: {}', len(packet), packet.hex())
+                _LOGGER.debug('Send [%d]: %s', len(packet), packet.hex())
                 self._send_packet_queue.task_done()
             except asyncio.TimeoutError:
                 continue
             except Exception as ex:
-                _LOGGER.error('writer error, {}', ex)
+                _LOGGER.error('writer error, %s', ex)
                 self._loop.create_task(self._async_reconnect())
                 break
         _LOGGER.debug('writer end')
